@@ -873,7 +873,7 @@ class DataValidator:
         invalid_data = (
             categorical_data
             .join(levels_df, left_on=["feature", "value"], right_on=["feature", "allowed_value"], how="left")
-            .filter(pl.col("allowed_value").is_null())  # Invalid values will have null allowed_value
+            .filter(pl.col("feature").is_null())  # Invalid values will have null allowed_value
         )
 
         if not invalid_data.is_empty():
@@ -904,10 +904,8 @@ class DataValidator:
     def _validate_text_feature_values(self, description: pl.DataFrame, data: pl.DataFrame) -> None:
         """Validate that text feature values are strings or null."""
 
-        if description.select(pl.col("var_type") == VariableTypes.TEXT.value).is_empty():
-            print("No text features to validate.")
+        if description.filter(pl.col("var_type") == VariableTypes.TEXT.value).is_empty():
             return  # No text features to validate
-        print(description)
 
         # If text features present, the entire value columns must be String
         if data.select(pl.col("value")).dtypes[0] != pl.Utf8:
